//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
// DSE.inc:     Pascal/Delphi Header for DSE.dll
//---------------------------------------------------------------------------
//---------------------------------------------------------------------------


//---------------------------------------------------------------------------
// Public Constants:
//---------------------------------------------------------------------------
const

// Baudrate Parameters:
//---------------------
  DSE_RATE_38400            = 38400;
  DSE_RATE_115200           = 115200;
  DSE_RATE_230400           = 230400;
  DSE_RATE_460800           = 460800;
  DSE_RATE_921600           = 921600;


// Telegram Size Parameters:
//--------------------------
  DSE_BITS_16               = 16;
  DSE_BITS_18               = 18;


// Boolean Returns:
//-----------------
  DSE_SUCCESS               = 1;
  DSE_FAILURE               = 0;


// Invalid Return:
//----------------
  DSE_INVALID               = -1;


// Sensor Status Bitmasks:
//------------------------
  DSE_OK                    = 0;    // No errors, queue stopped.
  DSE_CLOSED                = 1;    // Port closed.
  DSE_STARTED               = 2;    // Queue started.
  DSE_OVERFLOW              = 4;    // Queue overflowed.
  DSE_NOSYNC                = 8;    // No synchronisation.
  DSE_SYNCERROR             = 16;   // No sync. (persistent / manual clear).


// Comm Status Bitmasks:
//----------------------
  DSE_COMMERROR             = 128;  // Comm port error.
  DSE_COMMSTALL             = 256;  // No incomming data on comm port.


// Select-X Bit Numbers:
//----------------------
  DSE_BIT_EXTMODE   = 0;            // Extended Measurement Mode.
  DSE_BIT_LVLMODE   = 1;            // Level Mode.
  DSE_BIT_ERRMODE   = 2;            // Disable Light Intensity Codes.
  DSE_BIT_SAMMODE   = 3;            // Sample-Hold Mode.
  DSE_BIT_DIFMODE   = 4;            // Difference Mode.


// Select-X Parameter Numbers:
//----------------------------
  DSE_PAR_RUNSIZE   = 1;            // Running Avg. filter size (0=disable).
  DSE_PAR_RUNZERO   = 2;            // Running Avg. filter max. zero count.
  DSE_PAR_COMRATE   = 3;            // Comm port baudrate.
  DSE_PAR_MEDSIZE   = 4;            // Median filter size (0=disable).
  DSE_PAR_AVGSIZE   = 5;            // Simple Avg. filter size (0=disable).


// Select-X Special Parameter Numbers:
//------------------------------------
  DSE_PAR_COLIGHT   = 12;           // Extra Light Constant.
  DSE_PAR_EXLIGHT   = 13;           // Extra Light Modes.
  DSE_PAR_MFILTER   = 14;           // Custom Modes.


// Select-X Special Parameter Values:
//-----------------------------------
  DSE_VAL_HTLIGHT   = 8866;         // Extra Light - HighTemp mode.
  DSE_VAL_SLLIGHT   = 1213;         // Extra Light - Slow mode.
  DSE_VAL_MOLIGHT   = 1211;         // Extra Light - Moderate mode.
  DSE_VAL_COLIGHT   = 1212;         // Extra Light - Constant mode.
  DSE_VAL_CUSTMED   = 2424;         // Custom Mode - Custom Median Filter.
  DSE_VAL_MFILTER   = 2627;         // Custom Mode - Disable Math Filter.


//---------------------------------------------------------------------------
// Public Functions
//---------------------------------------------------------------------------


// Standard functions:
//--------------------
function DSE_Open(PortNumber: Integer): Integer; stdcall; external 'DSE.dll' index 1
function DSE_OpenSim(FileName: CString, SensorRate: Integer): Integer; stdcall; external 'DSE.dll' index 2
function DSE_OpenTcp(HostName: CString, PortNumber: Integer, SensorBits: Integer): Integer; stdcall; external 'DSE.dll' index 34
function DSE_Close: Integer; stdcall; external 'DSE.dll' index 3

function DSE_StartQueue: Integer; stdcall; external 'DSE.dll' index 4
function DSE_StopQueue: Integer; stdcall; external 'DSE.dll' index 5

function DSE_PeekValue: Integer; stdcall; external 'DSE.dll' index 6
function DSE_PeekQueue: Integer; stdcall; external 'DSE.dll' index 7
function DSE_PopQueue: Integer; stdcall; external 'DSE.dll' index 8

function DSE_QueueSize: Integer; stdcall; external 'DSE.dll' index 9
function DSE_ClearQueue: Integer; stdcall; external 'DSE.dll' index 10
function DSE_Status(ClearPersistent: Boolean=false): Integer; stdcall; external 'DSE.dll' index 11

function DSE_GetSerial: Integer; stdcall; external 'DSE.dll' index 12
function DSE_ReadTemp: Integer; stdcall; external 'DSE.dll' index 13


// Select-X functions:
//--------------------
function DSESEL_Check: Integer; stdcall; external 'DSE.dll' index 14
function DSESEL_GetBit(int Index): Integer; stdcall; external 'DSE.dll' index 15
function DSESEL_GetPar(int Index): Integer; stdcall; external 'DSE.dll' index 16

function DSESEL_SetBit(int Index, int Value); stdcall; external 'DSE.dll' index 17
function DSESEL_SetPar(int Index, int Value); stdcall; external 'DSE.dll' index 18
function DSESEL_Select(bool Flag=false, bool Reset=false); stdcall; external 'DSE.dll' index 19


// Detect functions:
//------------------
function DSEDET_DetectPorts: Integer; stdcall; external 'DSE.dll' index 20
function DSEDET_GetPort(Index: Integer): Integer; stdcall; external 'DSE.dll' index 21

function DSEDET_DetectSensors(FirstOnly: Boolean=false): Integer; stdcall; external 'DSE.dll' index 22
function DSEDET_GetSensorPort(Index: Integer): Integer; stdcall; external 'DSE.dll' index 23
function DSEDET_GetSensorRate(Index: Integer): Integer; stdcall; external 'DSE.dll' index 24
function DSEDET_GetSensorBits(Index: Integer): Integer; stdcall; external 'DSE.dll' index 25


// Camera functions:
//------------------
function DSE_CON DSECAM_Enable; stdcall; external 'DSE.dll' index 26
function DSE_CON DSECAM_Finish; stdcall; external 'DSE.dll' index 27

function DSE_CON DSECAM_GotNew: Boolean; stdcall; external 'DSE.dll' index 28

function DSECAM_GetAdr(void): Integer; stdcall; external 'DSE.dll' index 29
function DSECAM_GetReg(void): Integer; stdcall; external 'DSE.dll' index 30
function DSECAM_GetVal(void): Integer; stdcall; external 'DSE.dll' index 31

function DSECAM_GetPix(Index: Integer): Byte; stdcall; external 'DSE.dll' index 32


//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
// End of DSE.inc
